@@ -1,4 +1,3 @@
-
 import numpy as np
 import pandas as pd
 
@@ -12,10 +11,20 @@ def label_encoding_sklearn(df, colonna):
     le = LabelEncoder()
     return(le.fit_transform(df[colonna]))
 
+#make function ro label encoding multiple columns of dataframe
+def label_encoding_multiplo(df, lista_colonne):
+    for colonna in lista_colonne:
+        df[colonna] = label_encoding(df, colonna)
+    return(df)
+
 #make function to onehot encoding categorical values
 def onehot_encoding(df, colonna):
     return(pd.get_dummies(df[colonna]))
 
+#make function to remove duplicates from dataframe
+def rimuovi_duplicati(df):
+    return(df.drop_duplicates())
+
 #make function to replace missing values with passed value
 def sostituisci_nan(df, valore):
     return(df.fillna(valore))
